/*
 * pic18f1330.h - device specific declarations
 *
 * This file is part of the GNU PIC library for SDCC,
 * originally devised by Vangelis Rokas <vrokas AT otenet.gr>
 *
 * It has been automatically generated by inc2h-pic16.pl,
 * (c) 2007 by Raphael Neider <rneider AT web.de>
 *
 * SDCC is licensed under the GNU Public license (GPL) v2. Note that
 * this license covers the code to the compiler and other executables,
 * tbut explicitly does not cover any code or objects generated by sdcc.
 *
 * For pic device libraries and header files which are derived from
 * Microchip header (.inc) and linker script (.lkr) files Microchip
 * requires that "The header files should state that they are only to be
 * used with authentic Microchip devices" which makes them incompatible
 * with the GPL. Pic device libraries and header files are located at
 * non-free/lib and non-free/include directories respectively.
 * Sdcc should be run with the --use-non-free command line option in
 * order to include non-free header files and libraries.
 *
 * See http://sdcc.sourceforge.net/ for the latest information on sdcc.
 */

#ifndef __PIC18F1330_H__
#define __PIC18F1330_H__ 1



// Configuration Bits
#define __CONFIG1H              0x300001
#define __CONFIG2L              0x300002
#define __CONFIG2H              0x300003
#define __CONFIG3L              0x300004
#define __CONFIG3H              0x300005
#define __CONFIG4L              0x300006
#define __CONFIG5L              0x300008
#define __CONFIG5H              0x300009
#define __CONFIG6L              0x30000A
#define __CONFIG6H              0x30000B
#define __CONFIG7L              0x30000C
#define __CONFIG7H              0x30000D

// CONFIG1H Options
#define _OSC_LP_1H              0xF0     // LP Oscillator
#define _OSC_XT_1H              0xF1     // XT Oscillator
#define _OSC_HS_1H              0xF2     // HS Oscillator
#define _OSC_RC_1H              0xF3     // External RC oscillator, CLKO function on RA6
#define _OSC_EC_1H              0xF4     // EC oscillator, CLKO function on RA6
#define _OSC_ECIO_1H            0xF5     // EC oscillator, port function on RA6
#define _OSC_HSPLL_1H           0xF6     // HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)
#define _OSC_RCIO_1H            0xF7     // External RC oscillator, port function on RA6
#define _OSC_INTIO2_1H          0xF8     // Internal oscillator, port function on RA6 and RA7
#define _OSC_INTIO1_1H          0xF9     // Internal oscillator, CLKO function on RA6, port function on RA7
#define _FCMEN_OFF_1H           0xBF     // Fail-Safe Clock Monitor disabled
#define _FCMEN_ON_1H            0xFF     // Fail-Safe Clock Monitor enabled
#define _IESO_OFF_1H            0x7F     // Oscillator Switchover mode disabled
#define _IESO_ON_1H             0xFF     // Oscillator Switchover mode enabled

// CONFIG2L Options
#define _PWRT_ON_2L             0xFE     // PWRT enabled
#define _PWRT_OFF_2L            0xFF     // PWRT disabled
#define _BOR_OFF_2L             0xF9     // Brown-out Reset disabled in hardware and software
#define _BOR_SBORENCTRL_2L      0xFB     // Brown-out Reset enabled and controlled by software (SBOREN is enabled)
#define _BOR_BOACTIVE_2L        0xFD     // Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)
#define _BOR_BOHW_2L            0xFF     // Brown-out Reset enabled in hardware only (SBOREN is disabled)
#define _BORV_0_2L              0xF3     // Maximum setting
#define _BORV_1_2L              0xF7     //
#define _BORV_2_2L              0xFB     //
#define _BORV_3_2L              0xFF     // Minimum setting

// CONFIG2H Options
#define _WDT_OFF_2H             0xFE     // WDT disabled (control is placed on the SWDTEN bit)
#define _WDT_ON_2H              0xFF     // WDT enabled
#define _WDTPS_1_2H             0xE1     // 1:1
#define _WDTPS_2_2H             0xE3     // 1:2
#define _WDTPS_4_2H             0xE5     // 1:4
#define _WDTPS_8_2H             0xE7     // 1:8
#define _WDTPS_16_2H            0xE9     // 1:16
#define _WDTPS_32_2H            0xEB     // 1:32
#define _WDTPS_64_2H            0xED     // 1:64
#define _WDTPS_128_2H           0xEF     // 1:128
#define _WDTPS_256_2H           0xF1     // 1:256
#define _WDTPS_512_2H           0xF3     // 1:512
#define _WDTPS_1024_2H          0xF5     // 1:1024
#define _WDTPS_2048_2H          0xF7     // 1:2048
#define _WDTPS_4096_2H          0xF9     // 1:4096
#define _WDTPS_8192_2H          0xFB     // 1:8192
#define _WDTPS_16384_2H         0xFD     // 1:16384
#define _WDTPS_32768_2H         0xFF     // 1:32768

// CONFIG3L Options
#define _HPOL_LOW_3L            0xF7     // PWM1, PWM3 and PWM5 are active-low
#define _HPOL_HIGH_3L           0xFF     // PWM1, PWM3 and PWM5 are active-high (default)
#define _LPOL_LOW_3L            0xFB     // PWM0, PWM2 and PWM4 are active-low
#define _LPOL_HIGH_3L           0xFF     // PWM0, PWM2 and PWM4 are active-high (default)
#define _PWMPIN_ON_3L           0xFD     // PWM outputs drive active states upon Reset
#define _PWMPIN_OFF_3L          0xFF     // PWM outputs disabled upon Reset

// CONFIG3H Options
#define _FLTAMX_RA7_3H          0xFE     // FLTA input is muxed onto RA7
#define _FLTAMX_RA5_3H          0xFF     // FLTA input is muxed onto RA5
#define _T1OSCMX_LOW_3H         0xF7     // T1OSO/T1CKI pin resides on RB2
#define _T1OSCMX_HIGH_3H        0xFF     // T1OSO/T1CKI pin resides on RA6
#define _MCLRE_OFF_3H           0x7F     // RA5 input pin enabled, MCLR pin disabled
#define _MCLRE_ON_3H            0xFF     // MCLR pin enabled, RA5 input pin disabled

// CONFIG4L Options
#define _STVREN_OFF_4L          0xFE     // Reset on stack overflow/underflow disabled
#define _STVREN_ON_4L           0xFF     // Reset on stack overflow/underflow enabled
#define _BBSIZ_BB256_4L         0xCF     // 256 Words (512 Bytes)
#define _BBSIZ_BB512_4L         0xDF     // 512 Words (1024 Bytes)
#define _BBSIZ_BB1K_4L          0xFF     // 1K Words (2048 Bytes)
#define _XINST_OFF_4L           0xBF     // Instruction set extension and Indexed Addressing mode disabled
#define _XINST_ON_4L            0xFF     // Instruction set extension and Indexed Addressing mode enabled
#define _DEBUG_ON_4L            0x7F     // Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug
#define _DEBUG_OFF_4L           0xFF     // Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins

// CONFIG5L Options
#define _CP0_ON_5L              0xFE     // Block 0 is code-protected
#define _CP0_OFF_5L             0xFF     // Block 0 is not code-protected
#define _CP1_ON_5L              0xFD     // Block 1 is code-protected
#define _CP1_OFF_5L             0xFF     // Block 1 is not code-protected

// CONFIG5H Options
#define _CPB_ON_5H              0xBF     // Boot Block is code-protected
#define _CPB_OFF_5H             0xFF     // Boot Block is not code-protected
#define _CPD_ON_5H              0x7F     // Data EEPROM is code-protected
#define _CPD_OFF_5H             0xFF     // Data EEPROM is not code-protected

// CONFIG6L Options
#define _WRT0_ON_6L             0xFE     // Block 0 is write-protected
#define _WRT0_OFF_6L            0xFF     // Block 0 is not write-protected
#define _WRT1_ON_6L             0xFD     // Block 1 is write-protected
#define _WRT1_OFF_6L            0xFF     // Block 1 is not write-protected

// CONFIG6H Options
#define _WRTB_ON_6H             0xBF     // Boot Block is write-protected
#define _WRTB_OFF_6H            0xFF     // Boot Block is not write-protected
#define _WRTC_ON_6H             0xDF     // Configuration registers are write-protected
#define _WRTC_OFF_6H            0xFF     // Configuration registers are not write-protected
#define _WRTD_ON_6H             0x7F     // Data EEPROM is write-protected
#define _WRTD_OFF_6H            0xFF     // Data EEPROM is not write-protected

// CONFIG7L Options
#define _EBTR0_ON_7L            0xFE     // Block 0 is protected from table reads executed in other blocks
#define _EBTR0_OFF_7L           0xFF     // Block 0 is not protected from table reads executed in other blocks
#define _EBTR1_ON_7L            0xFD     // Block 1 is protected from table reads executed in other blocks
#define _EBTR1_OFF_7L           0xFF     // Block 1 is not protected from table reads executed in other blocks

// CONFIG7H Options
#define _EBTRB_ON_7H            0xBF     // Boot Block is protected from table reads executed in other blocks
#define _EBTRB_OFF_7H           0xFF     // Boot Block is not protected from table reads executed in other blocks
#define _DEVID1                 0x3FFFFE
#define _DEVID2                 0x3FFFFF
#define _IDLOC0                 0x200000
#define _IDLOC1                 0x200001
#define _IDLOC2                 0x200002
#define _IDLOC3                 0x200003
#define _IDLOC4                 0x200004
#define _IDLOC5                 0x200005
#define _IDLOC6                 0x200006
#define _IDLOC7                 0x200007

extern __sfr __at (0xF80) PORTA;
typedef union {
        struct {
                unsigned RA0            : 1;
                unsigned RA1            : 1;
                unsigned RA2            : 1;
                unsigned RA3            : 1;
                unsigned RA4            : 1;
                unsigned RA5            : 1;
                unsigned RA6            : 1;
                unsigned RA7            : 1;
        };
        struct {
                unsigned AN0            : 1;
                unsigned AN1            : 1;
                unsigned TX             : 1;
                unsigned RX             : 1;
                unsigned AN2            : 1;
                unsigned MCLR           : 1;
                unsigned OSC2           : 1;
                unsigned OSC1           : 1;
        };
        struct {
                unsigned INT0           : 1;
                unsigned INT1           : 1;
                unsigned CK             : 1;
                unsigned DT             : 1;
                unsigned T0CKI          : 1;
                unsigned NOT_MCLR       : 1;
                unsigned CLKO           : 1;
                unsigned CLKI           : 1;
        };
        struct {
                unsigned KBI0           : 1;
                unsigned KBI1           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned VREFP          : 1;
                unsigned                : 1;
                unsigned T1OSO_PORTA    : 1;
                unsigned T1OSI_PORTA    : 1;
        };
        struct {
                unsigned CMP0           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned AN3            : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned T1CKI_PORTA    : 1;
                unsigned                : 1;
        };
} __PORTAbits_t;
extern volatile __PORTAbits_t __at (0xF80) PORTAbits;

extern __sfr __at (0xF81) PORTB;
typedef union {
        struct {
                unsigned RB0            : 1;
                unsigned RB1            : 1;
                unsigned RB2            : 1;
                unsigned RB3            : 1;
                unsigned RB4            : 1;
                unsigned RB5            : 1;
                unsigned RB6            : 1;
                unsigned RB7            : 1;
        };
        struct {
                unsigned PWM0           : 1;
                unsigned PWM1           : 1;
                unsigned INT2           : 1;
                unsigned INT3           : 1;
                unsigned PWM2           : 1;
                unsigned PWM3           : 1;
                unsigned PWM4           : 1;
                unsigned PWM5           : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned KBI2           : 1;
                unsigned KBI3           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned PGC            : 1;
                unsigned PGD            : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned CMP2           : 1;
                unsigned CMP1           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned T1OSO_PORTB    : 1;
                unsigned T1OSI_PORTB    : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned T1CKI_PORTB    : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __PORTBbits_t;
extern volatile __PORTBbits_t __at (0xF81) PORTBbits;

extern __sfr __at (0xF82) OVDCONS;
typedef union {
        struct {
                unsigned POUT0          : 1;
                unsigned POUT1          : 1;
                unsigned POUT2          : 1;
                unsigned POUT3          : 1;
                unsigned POUT4          : 1;
                unsigned POUT5          : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __OVDCONSbits_t;
extern volatile __OVDCONSbits_t __at (0xF82) OVDCONSbits;

extern __sfr __at (0xF83) OVDCOND;
typedef union {
        struct {
                unsigned POVD0          : 1;
                unsigned POVD1          : 1;
                unsigned POVD2          : 1;
                unsigned POVD3          : 1;
                unsigned POVD4          : 1;
                unsigned POVD5          : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __OVDCONDbits_t;
extern volatile __OVDCONDbits_t __at (0xF83) OVDCONDbits;

extern __sfr __at (0xF84) DTCON;
typedef union {
        struct {
                unsigned DT0            : 1;
                unsigned DT1            : 1;
                unsigned DT2            : 1;
                unsigned DT3            : 1;
                unsigned DT4            : 1;
                unsigned DT5            : 1;
                unsigned DTPS0          : 1;
                unsigned DTPS1          : 1;
        };
} __DTCONbits_t;
extern volatile __DTCONbits_t __at (0xF84) DTCONbits;

extern __sfr __at (0xF85) PWMCON1;
typedef union {
        struct {
                unsigned OSYNC          : 1;
                unsigned UDIS           : 1;
                unsigned                : 1;
                unsigned SEVTDIR        : 1;
                unsigned SEVOPS0        : 1;
                unsigned SEVOPS1        : 1;
                unsigned SEVOPS2        : 1;
                unsigned SEVOPS3        : 1;
        };
} __PWMCON1bits_t;
extern volatile __PWMCON1bits_t __at (0xF85) PWMCON1bits;

extern __sfr __at (0xF86) PWMCON0;
typedef union {
        struct {
                unsigned PMOD0          : 1;
                unsigned PMOD1          : 1;
                unsigned PMOD2          : 1;
                unsigned                : 1;
                unsigned PWMEN0         : 1;
                unsigned PWMEN1         : 1;
                unsigned PWMEN2         : 1;
                unsigned                : 1;
        };
} __PWMCON0bits_t;
extern volatile __PWMCON0bits_t __at (0xF86) PWMCON0bits;

extern __sfr __at (0xF87) SEVTCMPH;

extern __sfr __at (0xF88) SEVTCMPL;

extern __sfr __at (0xF89) LATA;
typedef union {
        struct {
                unsigned LATA0          : 1;
                unsigned LATA1          : 1;
                unsigned LATA2          : 1;
                unsigned LATA3          : 1;
                unsigned LATA4          : 1;
                unsigned                : 1;
                unsigned LATA6          : 1;
                unsigned LATA7          : 1;
        };
} __LATAbits_t;
extern volatile __LATAbits_t __at (0xF89) LATAbits;

extern __sfr __at (0xF8A) LATB;
typedef union {
        struct {
                unsigned LATB0          : 1;
                unsigned LATB1          : 1;
                unsigned LATB2          : 1;
                unsigned LATB3          : 1;
                unsigned LATB4          : 1;
                unsigned LATB5          : 1;
                unsigned LATB6          : 1;
                unsigned LATB7          : 1;
        };
} __LATBbits_t;
extern volatile __LATBbits_t __at (0xF8A) LATBbits;

extern __sfr __at (0xF8B) FLTCONFIG;
typedef union {
        struct {
                unsigned FLTAEN         : 1;
                unsigned FLTAMOD        : 1;
                unsigned FLTAS          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned BRFEN          : 1;
        };
} __FLTCONFIGbits_t;
extern volatile __FLTCONFIGbits_t __at (0xF8B) FLTCONFIGbits;

extern __sfr __at (0xF8C) PDC2H;

extern __sfr __at (0xF8D) PDC2L;

extern __sfr __at (0xF8E) PDC1H;

extern __sfr __at (0xF8F) PDC1L;

extern __sfr __at (0xF90) PDC0H;

extern __sfr __at (0xF91) PDC0L;

extern __sfr __at (0xF92) DDRA;
typedef union {
        struct {
                unsigned RA0            : 1;
                unsigned RA1            : 1;
                unsigned RA2            : 1;
                unsigned RA3            : 1;
                unsigned RA4            : 1;
                unsigned RA5            : 1;
                unsigned RA6            : 1;
                unsigned RA7            : 1;
        };
} __DDRAbits_t;
extern volatile __DDRAbits_t __at (0xF92) DDRAbits;

extern __sfr __at (0xF92) TRISA;
typedef union {
        struct {
                unsigned TRISA0         : 1;
                unsigned TRISA1         : 1;
                unsigned TRISA2         : 1;
                unsigned TRISA3         : 1;
                unsigned TRISA4         : 1;
                unsigned                : 1;
                unsigned TRISA6         : 1;
                unsigned TRISA7         : 1;
        };
} __TRISAbits_t;
extern volatile __TRISAbits_t __at (0xF92) TRISAbits;

extern __sfr __at (0xF93) DDRB;
typedef union {
        struct {
                unsigned RB0            : 1;
                unsigned RB1            : 1;
                unsigned RB2            : 1;
                unsigned RB3            : 1;
                unsigned RB4            : 1;
                unsigned RB5            : 1;
                unsigned RB6            : 1;
                unsigned RB7            : 1;
        };
} __DDRBbits_t;
extern volatile __DDRBbits_t __at (0xF93) DDRBbits;

extern __sfr __at (0xF93) TRISB;
typedef union {
        struct {
                unsigned TRISB0         : 1;
                unsigned TRISB1         : 1;
                unsigned TRISB2         : 1;
                unsigned TRISB3         : 1;
                unsigned TRISB4         : 1;
                unsigned TRISB5         : 1;
                unsigned TRISB6         : 1;
                unsigned TRISB7         : 1;
        };
} __TRISBbits_t;
extern volatile __TRISBbits_t __at (0xF93) TRISBbits;

extern __sfr __at (0xF95) PTPERH;

extern __sfr __at (0xF96) PTPERL;

extern __sfr __at (0xF97) PTMRH;

extern __sfr __at (0xF98) PTMRL;

extern __sfr __at (0xF99) PTCON1;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned PTDIR          : 1;
                unsigned PTEN           : 1;
        };
} __PTCON1bits_t;
extern volatile __PTCON1bits_t __at (0xF99) PTCON1bits;

extern __sfr __at (0xF9A) PTCON0;
typedef union {
        struct {
                unsigned PTMOD0         : 1;
                unsigned PTMOD1         : 1;
                unsigned PTCKPS0        : 1;
                unsigned PTCKPS1        : 1;
                unsigned PTOPS0         : 1;
                unsigned PTOPS1         : 1;
                unsigned PTOPS2         : 1;
                unsigned PTOPS3         : 1;
        };
} __PTCON0bits_t;
extern volatile __PTCON0bits_t __at (0xF9A) PTCON0bits;

extern __sfr __at (0xF9B) OSCTUNE;
typedef union {
        struct {
                unsigned TUN0           : 1;
                unsigned TUN1           : 1;
                unsigned TUN2           : 1;
                unsigned TUN3           : 1;
                unsigned TUN4           : 1;
                unsigned                : 1;
                unsigned PLLEN          : 1;
                unsigned INTSRC         : 1;
        };
} __OSCTUNEbits_t;
extern volatile __OSCTUNEbits_t __at (0xF9B) OSCTUNEbits;

extern __sfr __at (0xF9D) PIE1;
typedef union {
        struct {
                unsigned TMR1IE         : 1;
                unsigned CMP0IE         : 1;
                unsigned CMP1IE         : 1;
                unsigned CMP2IE         : 1;
                unsigned TXIE           : 1;
                unsigned RCIE           : 1;
                unsigned ADIE           : 1;
                unsigned                : 1;
        };
} __PIE1bits_t;
extern volatile __PIE1bits_t __at (0xF9D) PIE1bits;

extern __sfr __at (0xF9E) PIR1;
typedef union {
        struct {
                unsigned TMR1IF         : 1;
                unsigned CMP0IF         : 1;
                unsigned CMP1IF         : 1;
                unsigned CMP2IF         : 1;
                unsigned TXIF           : 1;
                unsigned RCIF           : 1;
                unsigned ADIF           : 1;
                unsigned                : 1;
        };
} __PIR1bits_t;
extern volatile __PIR1bits_t __at (0xF9E) PIR1bits;

extern __sfr __at (0xF9F) IPR1;
typedef union {
        struct {
                unsigned TMR1IP         : 1;
                unsigned CMP0IP         : 1;
                unsigned CMP1IP         : 1;
                unsigned CMP2IP         : 1;
                unsigned TXIP           : 1;
                unsigned RCIP           : 1;
                unsigned ADIP           : 1;
                unsigned                : 1;
        };
} __IPR1bits_t;
extern volatile __IPR1bits_t __at (0xF9F) IPR1bits;

extern __sfr __at (0xFA0) PIE2;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned LVDIE          : 1;
                unsigned                : 1;
                unsigned EEIE           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned OSCFIE         : 1;
        };
} __PIE2bits_t;
extern volatile __PIE2bits_t __at (0xFA0) PIE2bits;

extern __sfr __at (0xFA1) PIR2;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned LVDIF          : 1;
                unsigned                : 1;
                unsigned EEIF           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned OSCFIF         : 1;
        };
} __PIR2bits_t;
extern volatile __PIR2bits_t __at (0xFA1) PIR2bits;

extern __sfr __at (0xFA2) IPR2;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned LVDIP          : 1;
                unsigned                : 1;
                unsigned EEIP           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned OSCFIP         : 1;
        };
} __IPR2bits_t;
extern volatile __IPR2bits_t __at (0xFA2) IPR2bits;

extern __sfr __at (0xFA3) PIE3;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned PTIE           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __PIE3bits_t;
extern volatile __PIE3bits_t __at (0xFA3) PIE3bits;

extern __sfr __at (0xFA4) PIR3;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned PTIF           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __PIR3bits_t;
extern volatile __PIR3bits_t __at (0xFA4) PIR3bits;

extern __sfr __at (0xFA5) IPR3;
typedef union {
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned PTIP           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __IPR3bits_t;
extern volatile __IPR3bits_t __at (0xFA5) IPR3bits;

extern __sfr __at (0xFA6) EECON1;
typedef union {
        struct {
                unsigned RD             : 1;
                unsigned WR             : 1;
                unsigned WREN           : 1;
                unsigned WRERR          : 1;
                unsigned FREE           : 1;
                unsigned                : 1;
                unsigned CFGS           : 1;
                unsigned EEPGD          : 1;
        };
} __EECON1bits_t;
extern volatile __EECON1bits_t __at (0xFA6) EECON1bits;

extern __sfr __at (0xFA7) EECON2;

extern __sfr __at (0xFA8) EEDATA;

extern __sfr __at (0xFA9) EEADR;

extern __sfr __at (0xFAB) RCSTA;
typedef union {
        struct {
                unsigned RX9D           : 1;
                unsigned OERR           : 1;
                unsigned FERR           : 1;
                unsigned ADEN           : 1;
                unsigned CREN           : 1;
                unsigned SREN           : 1;
                unsigned RX9            : 1;
                unsigned SPEN           : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned ADDEN          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __RCSTAbits_t;
extern volatile __RCSTAbits_t __at (0xFAB) RCSTAbits;

extern __sfr __at (0xFAC) TXSTA;
typedef union {
        struct {
                unsigned TX9D           : 1;
                unsigned TRMT           : 1;
                unsigned BRGH           : 1;
                unsigned SENDB          : 1;
                unsigned SYNC           : 1;
                unsigned TXEN           : 1;
                unsigned TX9            : 1;
                unsigned CSRC           : 1;
        };
} __TXSTAbits_t;
extern volatile __TXSTAbits_t __at (0xFAC) TXSTAbits;

extern __sfr __at (0xFAD) TXREG;

extern __sfr __at (0xFAE) RCREG;

extern __sfr __at (0xFAF) SPBRG;

extern __sfr __at (0xFB0) SPBRGH;

extern __sfr __at (0xFB4) CMCON;
typedef union {
        struct {
                unsigned CMEN0          : 1;
                unsigned CMEN1          : 1;
                unsigned CMEN2          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned C0OUT          : 1;
                unsigned C1OUT          : 1;
                unsigned C2OUT          : 1;
        };
} __CMCONbits_t;
extern volatile __CMCONbits_t __at (0xFB4) CMCONbits;

extern __sfr __at (0xFB5) CVRCON;
typedef union {
        struct {
                unsigned CVR0           : 1;
                unsigned CVR1           : 1;
                unsigned CVR2           : 1;
                unsigned CVR3           : 1;
                unsigned CVREF          : 1;
                unsigned CVRR           : 1;
                unsigned                : 1;
                unsigned CVREN          : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned CVRSS          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __CVRCONbits_t;
extern volatile __CVRCONbits_t __at (0xFB5) CVRCONbits;

extern __sfr __at (0xFB8) BAUDCON;
typedef union {
        struct {
                unsigned ABDEN          : 1;
                unsigned WUE            : 1;
                unsigned                : 1;
                unsigned BRG16          : 1;
                unsigned SCKP           : 1;
                unsigned                : 1;
                unsigned RCIDL          : 1;
                unsigned ABDOVF         : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned RCMT           : 1;
                unsigned                : 1;
        };
} __BAUDCONbits_t;
extern volatile __BAUDCONbits_t __at (0xFB8) BAUDCONbits;

extern __sfr __at (0xFB8) BAUDCTL;
typedef union {
        struct {
                unsigned ABDEN          : 1;
                unsigned WUE            : 1;
                unsigned                : 1;
                unsigned BRG16          : 1;
                unsigned SCKP           : 1;
                unsigned                : 1;
                unsigned RCIDL          : 1;
                unsigned ABDOVF         : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned RCMT           : 1;
                unsigned                : 1;
        };
} __BAUDCTLbits_t;
extern volatile __BAUDCTLbits_t __at (0xFB8) BAUDCTLbits;

extern __sfr __at (0xFC0) ADCON2;
typedef union {
        struct {
                unsigned ADCS0          : 1;
                unsigned ADCS1          : 1;
                unsigned ADCS2          : 1;
                unsigned ACQT0          : 1;
                unsigned ACQT1          : 1;
                unsigned ACQT2          : 1;
                unsigned                : 1;
                unsigned ADFM           : 1;
        };
} __ADCON2bits_t;
extern volatile __ADCON2bits_t __at (0xFC0) ADCON2bits;

extern __sfr __at (0xFC1) ADCON1;
typedef union {
        struct {
                unsigned PCFG0          : 1;
                unsigned PCFG1          : 1;
                unsigned PCFG2          : 1;
                unsigned PCFG3          : 1;
                unsigned VCFG0          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __ADCON1bits_t;
extern volatile __ADCON1bits_t __at (0xFC1) ADCON1bits;

extern __sfr __at (0xFC2) ADCON0;
typedef union {
        struct {
                unsigned ADON           : 1;
                unsigned GO             : 1;
                unsigned CHS0           : 1;
                unsigned CHS1           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned SEVTEN         : 1;
        };
        struct {
                unsigned                : 1;
                unsigned DONE           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned NOT_DONE       : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned GO_DONE        : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __ADCON0bits_t;
extern volatile __ADCON0bits_t __at (0xFC2) ADCON0bits;

extern __sfr __at (0xFC3) ADRES;

extern __sfr __at (0xFC3) ADRESL;

extern __sfr __at (0xFC4) ADRESH;

extern __sfr __at (0xFCD) T1CON;
typedef union {
        struct {
                unsigned TMR1ON         : 1;
                unsigned TMR1CS         : 1;
                unsigned NOT_T1SYNC     : 1;
                unsigned T1OSCEN        : 1;
                unsigned T1CKPS0        : 1;
                unsigned T1CKPS1        : 1;
                unsigned T1RUN          : 1;
                unsigned RD16           : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned T1SYNC         : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __T1CONbits_t;
extern volatile __T1CONbits_t __at (0xFCD) T1CONbits;

extern __sfr __at (0xFCE) TMR1L;

extern __sfr __at (0xFCF) TMR1H;

extern __sfr __at (0xFD0) RCON;
typedef union {
        struct {
                unsigned NOT_BOR        : 1;
                unsigned NOT_POR        : 1;
                unsigned NOT_PD         : 1;
                unsigned NOT_TO         : 1;
                unsigned NOT_RI         : 1;
                unsigned                : 1;
                unsigned SBOREN         : 1;
                unsigned IPEN           : 1;
        };
        struct {
                unsigned BOR            : 1;
                unsigned POR            : 1;
                unsigned PD             : 1;
                unsigned TO             : 1;
                unsigned RI             : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __RCONbits_t;
extern volatile __RCONbits_t __at (0xFD0) RCONbits;

extern __sfr __at (0xFD1) WDTCON;
typedef union {
        struct {
                unsigned SWDTEN         : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned SWDTE          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __WDTCONbits_t;
extern volatile __WDTCONbits_t __at (0xFD1) WDTCONbits;

extern __sfr __at (0xFD2) LVDCON;
typedef union {
        struct {
                unsigned LVDL0          : 1;
                unsigned LVDL1          : 1;
                unsigned LVDL2          : 1;
                unsigned LVDL3          : 1;
                unsigned LVDEN          : 1;
                unsigned IRVST          : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned IVRST          : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __LVDCONbits_t;
extern volatile __LVDCONbits_t __at (0xFD2) LVDCONbits;

extern __sfr __at (0xFD3) OSCCON;
typedef union {
        struct {
                unsigned SCS0           : 1;
                unsigned SCS1           : 1;
                unsigned FLTS           : 1;
                unsigned OSTS           : 1;
                unsigned IRCF0          : 1;
                unsigned IRCF1          : 1;
                unsigned IRCF2          : 1;
                unsigned IDLEN          : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned IOFS           : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __OSCCONbits_t;
extern volatile __OSCCONbits_t __at (0xFD3) OSCCONbits;

extern __sfr __at (0xFD5) T0CON;
typedef union {
        struct {
                unsigned T0PS0          : 1;
                unsigned T0PS1          : 1;
                unsigned T0PS2          : 1;
                unsigned PSA            : 1;
                unsigned T0SE           : 1;
                unsigned T0CS           : 1;
                unsigned T016BIT        : 1;
                unsigned TMR0ON         : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned T08BIT         : 1;
                unsigned                : 1;
        };
} __T0CONbits_t;
extern volatile __T0CONbits_t __at (0xFD5) T0CONbits;

extern __sfr __at (0xFD6) TMR0L;

extern __sfr __at (0xFD7) TMR0H;

extern __sfr __at (0xFD8) STATUS;
typedef union {
        struct {
                unsigned C              : 1;
                unsigned DC             : 1;
                unsigned Z              : 1;
                unsigned OV             : 1;
                unsigned N              : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
        };
} __STATUSbits_t;
extern volatile __STATUSbits_t __at (0xFD8) STATUSbits;

extern __sfr __at (0xFD9) FSR2L;

extern __sfr __at (0xFDA) FSR2H;

extern __sfr __at (0xFDB) PLUSW2;

extern __sfr __at (0xFDC) PREINC2;

extern __sfr __at (0xFDD) POSTDEC2;

extern __sfr __at (0xFDE) POSTINC2;

extern __sfr __at (0xFDF) INDF2;

extern __sfr __at (0xFE0) BSR;

extern __sfr __at (0xFE1) FSR1L;

extern __sfr __at (0xFE2) FSR1H;

extern __sfr __at (0xFE3) PLUSW1;

extern __sfr __at (0xFE4) PREINC1;

extern __sfr __at (0xFE5) POSTDEC1;

extern __sfr __at (0xFE6) POSTINC1;

extern __sfr __at (0xFE7) INDF1;

extern __sfr __at (0xFE8) WREG;

extern __sfr __at (0xFE9) FSR0L;

extern __sfr __at (0xFEA) FSR0H;

extern __sfr __at (0xFEB) PLUSW0;

extern __sfr __at (0xFEC) PREINC0;

extern __sfr __at (0xFED) POSTDEC0;

extern __sfr __at (0xFEE) POSTINC0;

extern __sfr __at (0xFEF) INDF0;

extern __sfr __at (0xFF0) INTCON3;
typedef union {
        struct {
                unsigned INT1IF         : 1;
                unsigned INT2IF         : 1;
                unsigned INT3IF         : 1;
                unsigned INT1IE         : 1;
                unsigned INT2IE         : 1;
                unsigned INT3IE         : 1;
                unsigned INT1IP         : 1;
                unsigned INT2IP         : 1;
        };
        struct {
                unsigned INT1F          : 1;
                unsigned INT2F          : 1;
                unsigned INT3F          : 1;
                unsigned INT1E          : 1;
                unsigned INT2E          : 1;
                unsigned INT3E          : 1;
                unsigned INT1P          : 1;
                unsigned INT2P          : 1;
        };
} __INTCON3bits_t;
extern volatile __INTCON3bits_t __at (0xFF0) INTCON3bits;

extern __sfr __at (0xFF1) INTCON2;
typedef union {
        struct {
                unsigned RBIP           : 1;
                unsigned INT3IP         : 1;
                unsigned TMR0IP         : 1;
                unsigned INTEDG3        : 1;
                unsigned INTEDG2        : 1;
                unsigned INTEDG1        : 1;
                unsigned INTEDG0        : 1;
                unsigned NOT_RBPU       : 1;
        };
        struct {
                unsigned                : 1;
                unsigned INT3P          : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned RBPU           : 1;
        };
} __INTCON2bits_t;
extern volatile __INTCON2bits_t __at (0xFF1) INTCON2bits;

extern __sfr __at (0xFF2) INTCON;
typedef union {
        struct {
                unsigned RBIF           : 1;
                unsigned INT0IF         : 1;
                unsigned TMR0IF         : 1;
                unsigned RBIE           : 1;
                unsigned INT0IE         : 1;
                unsigned TMR0IE         : 1;
                unsigned PEIE           : 1;
                unsigned GIE            : 1;
        };
        struct {
                unsigned                : 1;
                unsigned INT0F          : 1;
                unsigned T0IF           : 1;
                unsigned                : 1;
                unsigned INT0E          : 1;
                unsigned T0IE           : 1;
                unsigned GIEL           : 1;
                unsigned GIEH           : 1;
        };
} __INTCONbits_t;
extern volatile __INTCONbits_t __at (0xFF2) INTCONbits;

extern __sfr __at (0xFF3) PROD;

extern __sfr __at (0xFF3) PRODL;

extern __sfr __at (0xFF4) PRODH;

extern __sfr __at (0xFF5) TABLAT;

extern __sfr __at (0xFF6) TBLPTR;

extern __sfr __at (0xFF6) TBLPTRL;

extern __sfr __at (0xFF7) TBLPTRH;

extern __sfr __at (0xFF8) TBLPTRU;

extern __sfr __at (0xFF9) PC;

extern __sfr __at (0xFF9) PCL;

extern __sfr __at (0xFFA) PCLATH;

extern __sfr __at (0xFFB) PCLATU;

extern __sfr __at (0xFFC) STKPTR;
typedef union {
        struct {
                unsigned SP0            : 1;
                unsigned SP1            : 1;
                unsigned SP2            : 1;
                unsigned SP3            : 1;
                unsigned SP4            : 1;
                unsigned                : 1;
                unsigned STKUNF         : 1;
                unsigned STKOVF         : 1;
        };
        struct {
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned                : 1;
                unsigned STKFUL         : 1;
                unsigned                : 1;
        };
} __STKPTRbits_t;
extern volatile __STKPTRbits_t __at (0xFFC) STKPTRbits;

extern __sfr __at (0xFFD) TOS;

extern __sfr __at (0xFFD) TOSL;

extern __sfr __at (0xFFE) TOSH;

extern __sfr __at (0xFFF) TOSU;


#endif

